==> merchant-base-0.5.1-RELEASE-sources.jar: com/rocogz/merchant/response/agent/goods/MerchantAgentGoodsListResp.java <==
package com.rocogz.merchant.response.agent.goods;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.rocogz.merchant.entity.agent.goods.MerchantAgentGoods;
import lombok.Data;

import java.math.BigDecimal;

/**
 *代理商产品列表实体类
 * @author djt
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class MerchantAgentGoodsListResp extends MerchantAgentGoods {

    /**
     * 平台产品状态
     */
    private String merchantGoodsStatus;

    /**
     *代理商简称
     */
    private String agentName;


    /**
     *列表图:路径可能会被分割成几个对应比列的图
     */
    private String listView;


    /**
     * 平台产品商品名称
     */
    private String merchantGoodsName;

    /**
     * 平台产品商品简称
     */
    private String merchantGoodsAbbreviation;

    /**
     * 产品类型编码
     */
    private String goodsClassificationCode;

    /**
     * 产品类型编码
     */
    private String goodsClassificationName;

    /**
     * 供应商名称
     */
    private String supplierName;

    /**
     * 供应商编码
     */
    private String supplierCode;


    /**
     * 品牌名称
     */
    private String brandName;

    /**
     * 品牌名称
     */
    private String brandCode;

    /**
     * 代理商产品类型
     */
    private String goodsType;

    /**
     * 平台产品市场价
     */
    private String merchantGoodsMarketPrice;

    /**
     * 供应商产品编号
     */
    private String supplierGoodsCode;

    /**
     * 供应商产品名称
     */
    private String supplierGoodsName;

    /**
     * 平台产品类型
     */
    private String productTypeName;

    /**
     * 模型
     */
    private String model;

    /**
     * 平台产品的内容
     */
    private String goodsContent;


    /**
     * 卡券左上角标签
     */
    private String cardCouponLeftCornerLabel;

    /**
     * 卡券金额下方注释内容
     */
    private String cardCouponNotes;

    /**
     * 产品性质
     */
    private String goodsNature;


    /**
     * 如果是套餐,包含的套餐子项个数
     */
    private int suitItemCount;


    private BigDecimal suggestExchangePointValue;

}

==> merchant-base-0.5.61-RELEASE-sources.jar: com/rocogz/merchant/response/agent/goods/MerchantAgentGoodsListResp.java <==
package com.rocogz.merchant.response.agent.goods;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.rocogz.merchant.entity.agent.goods.MerchantAgentGoods;
import com.rocogz.merchant.entity.goods.MerchantGoods;
import lombok.Data;

import java.math.BigDecimal;

/**
 *代理商产品列表实体类
 * @author djt
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class MerchantAgentGoodsListResp extends MerchantAgentGoods {

    /**
     * 平台产品状态
     */
    private String merchantGoodsStatus;

    /**
     *代理商简称
     */
    private String agentName;


    /**
     *列表图:路径可能会被分割成几个对应比列的图
     */
    private String listView;


    /**
     * 平台产品商品名称
     */
    private String merchantGoodsName;

    /**
     * 平台产品商品简称
     */
    private String merchantGoodsAbbreviation;

    /**
     * 产品类型编码
     */
    private String goodsClassificationCode;

    /**
     * 产品类型编码
     */
    private String goodsClassificationName;

    /**
     * 供应商名称
     */
    private String supplierName;

    /**
     * 供应商编码
     */
    private String supplierCode;


    /**
     * 品牌名称
     */
    private String brandName;

    /**
     * 品牌名称
     */
    private String brandCode;

    /**
     * 代理商产品类型
     */
    private String goodsType;

    /**
     * 平台产品市场价
     */
    private String merchantGoodsMarketPrice;

    /**
     * 供应商产品编号
     */
    private String supplierGoodsCode;

    /**
     * 供应商产品名称
     */
    private String supplierGoodsName;

    /**
     * 平台产品类型
     */
    private String productTypeName;

    /**
     * 模型
     */
    private String model;

    /**
     * 平台产品的内容
     */
    private String goodsContent;


    /**
     * 卡券左上角标签
     */
    private String cardCouponLeftCornerLabel;

    /**
     * 卡券金额下方注释内容
     */
    private String cardCouponNotes;

    /**
     * 产品性质
     */
    private String goodsNature;


    /**
     * 如果是套餐,包含的套餐子项个数
     */
    private int suitItemCount;


    private BigDecimal suggestExchangePointValue;

    /**
     * 是否启用库存
     */
    private String whetherNeedStock;

    /**
     * 一句话亮点
     * @see MerchantGoods#saleLightPoint
     */
    private String saleLightPoint;

    /**
     * 使用有效期
     * @see MerchantGoods#useValidity
     */
    private Integer merchantGoodsUseValidity;

    /**
     * 是否虚拟商品(Y:是,N:否)
     *  @see MerchantGoods#invented
     */
    private String invented;

    /**
     * 左侧中部显示文案
     * MerchantGoods#leftMiddleDisplayDescribe
     */
    private String leftMiddleDisplayDescribe;


    /**
     * 这个其实是为空的，应为我们目前控制出库仓库的地方有两个地方
     * 1.主体可发放产品配置
     * 2.积分兑换产品配置的 这些都落在了响应的表中。
     *
     * 代理商产品上没有落地要出库的的仓库
     */
    private Integer sellableStock;

}
